@@ -26,6 +26,7 @@ from rdflib import (
     URIRef,
     XSD,
 )
+import validators
 
 from modelldcatnotordf.licensedocument import LicenseDocument
 
@@ -617,6 +618,8 @@ class ModelElement(ABC):
         "_has_property",
         "_dct_identifier",
         "_subject",
+        "_belongs_to_module",
+        "_description",
     )
 
     _g: Graph
@@ -625,6 +628,8 @@ class ModelElement(ABC):
     _dct_identifier: str
     _has_property: List[ModelProperty]
     _subject: Concept
+    _belongs_to_module: List[str]
+    _description: dict
 
     @abstractmethod
     def __init__(self) -> None:
@@ -682,6 +687,26 @@ class ModelElement(ABC):
         """Set for has_property."""
         self._has_property = has_property
 
+    @property
+    def belongs_to_module(self) -> List[str]:
+        """Get for belongs_to_module."""
+        return self._belongs_to_module
+
+    @belongs_to_module.setter
+    def belongs_to_module(self, belongs_to_module: List[str]) -> None:
+        """Set for belongs_to_module."""
+        self._belongs_to_module = belongs_to_module
+
+    @property
+    def description(self: ModelElement) -> dict:
+        """Get for description."""
+        return self._description
+
+    @description.setter
+    def description(self: ModelElement, description: dict) -> None:
+        """Set for description."""
+        self._description = description
+
     @abstractmethod
     def to_rdf(self, format: str = "turtle", encoding: Optional[str] = "utf-8") -> str:
         """Maps the modelelement to rdf.
@@ -739,8 +764,37 @@ class ModelElement(ABC):
         if getattr(self, "has_property", None):
             self._has_property_to_graph(selfobject)
 
+        self._belongs_to_module_to_graph(selfobject)
+
+        self._description_to_graph(selfobject)
+
         return self._g
 
+    def _belongs_to_module_to_graph(self: ModelElement, selfobject: Any) -> None:
+        if getattr(self, "belongs_to_module", None):
+
+            for belongs_to_module in self._belongs_to_module:
+                _datatype = XSD.anyURI if validators.url(belongs_to_module) else None
+
+                self._g.add(
+                    (
+                        selfobject,
+                        MODELLDCATNO.belongsToModule,
+                        Literal(belongs_to_module, datatype=_datatype),
+                    )
+                )
+
+    def _description_to_graph(self: ModelElement, selfobject: Any) -> None:
+        if getattr(self, "description", None):
+            for key in self.description:
+                self._g.add(
+                    (
+                        selfobject,
+                        DCTERMS.description,
+                        Literal(self.description[key], lang=key),
+                    )
+                )
+
     def _has_property_to_graph(self, _self: Any) -> None:
         if getattr(self, "has_property", None):
             for has_property in self._has_property:
@@ -779,6 +833,9 @@ class ModelProperty(ABC):
         "_max_occurs",
         "_title",
         "_subject",
+        "_description",
+        "_belongs_to_module",
+        "_forms_symmetry_with",
     )
 
     _g: Graph
@@ -788,6 +845,9 @@ class ModelProperty(ABC):
     _max_occurs: int
     _title: dict
     _subject: Concept
+    _description: dict
+    _belongs_to_module: List[str]
+    _forms_symmetry_with: ModelProperty
 
     @abstractmethod
     def __init__(self) -> None:
@@ -855,6 +915,38 @@ class ModelProperty(ABC):
         """Set for max_occurs."""
         self._max_occurs = max_occurs
 
+    @property
+    def description(self: ModelProperty) -> dict:
+        """Get for description."""
+        return self._description
+
+    @description.setter
+    def description(self: ModelProperty, description: dict) -> None:
+        """Set for description."""
+        self._description = description
+
+    @property
+    def belongs_to_module(self: ModelProperty) -> List[str]:
+        """Get for belongs_to_module."""
+        return self._belongs_to_module
+
+    @belongs_to_module.setter
+    def belongs_to_module(self: ModelProperty, belongs_to_module: List[str]) -> None:
+        """Set for belongs_to_module."""
+        self._belongs_to_module = belongs_to_module
+
+    @property
+    def forms_symmetry_with(self: ModelProperty) -> ModelProperty:
+        """Get for forms_symmetry_with."""
+        return self._forms_symmetry_with
+
+    @forms_symmetry_with.setter
+    def forms_symmetry_with(
+        self: ModelProperty, forms_symmetry_with: ModelProperty
+    ) -> None:
+        """Set for forms_symmetry_with."""
+        self._forms_symmetry_with = forms_symmetry_with
+
     @abstractmethod
     def to_rdf(self, format: str = "turtle", encoding: Optional[str] = "utf-8") -> str:
         """Maps the property to rdf.
@@ -911,6 +1003,10 @@ class ModelProperty(ABC):
 
             self._g.add((selfobject, DCTERMS.subject, _subject))
 
+        self._description_to_graph(selfobject)
+        self._belongs_to_module_to_graph(selfobject)
+        self._forms_symmetry_with_to_graph(selfobject)
+
         return self._g
 
     def _has_type_to_graph(self, _self: Any) -> None:
@@ -938,6 +1034,50 @@ class ModelProperty(ABC):
                     )
                 )
 
+    def _description_to_graph(self: ModelProperty, selfobject: Any) -> None:
+        if getattr(self, "description", None):
+            for key in self.description:
+                self._g.add(
+                    (
+                        selfobject,
+                        DCTERMS.description,
+                        Literal(self.description[key], lang=key),
+                    )
+                )
+
+    def _belongs_to_module_to_graph(self: ModelProperty, selfobject: Any) -> None:
+        if getattr(self, "belongs_to_module", None):
+
+            for belongs_to_module in self._belongs_to_module:
+                _datatype = XSD.anyURI if validators.url(belongs_to_module) else None
+
+                self._g.add(
+                    (
+                        selfobject,
+                        MODELLDCATNO.belongsToModule,
+                        Literal(belongs_to_module, datatype=_datatype),
+                    )
+                )
+
+    def _forms_symmetry_with_to_graph(self, _self: Any) -> None:
+
+        if getattr(self, "forms_symmetry_with", None):
+
+            if getattr(self.forms_symmetry_with, "identifier", None):
+                _forms_symmetry_with = URIRef(self.forms_symmetry_with.identifier)
+            else:
+                _forms_symmetry_with = BNode()
+                for _s, p, o in self.forms_symmetry_with._to_graph().triples(
+                    (None, None, None)
+                ):
+                    self._g.add(
+                        (_forms_symmetry_with, p, o)
+                        if isinstance(_forms_symmetry_with, BNode)
+                        else (_s, p, o)
+                    )
+
+            self._g.add((_self, MODELLDCATNO.formsSymmetryWith, _forms_symmetry_with))
+
 
 class Role(ModelProperty):
     """A class representing a modelldcatno:Role."""
@@ -1029,6 +1169,7 @@ class ObjectType(ModelElement):
     _identifier: URI
     _dct_identifier: str
     _g: Graph
+    _belongs_to_module: List[str]
 
     def __init__(self) -> None:
         """Inits an object with default values."""
@@ -1097,6 +1238,7 @@ class SimpleType(ModelElement):
     _min_inclusive: float
     _type_definition_reference: URI
     _pattern: str
+    _belongs_to_module: List[str]
 
     def __init__(self) -> None:
         """Inits an object with default values."""
@@ -2011,6 +2153,7 @@ class DataType(ModelElement):
     _identifier: URI
     _dct_identifier: str
     _g: Graph
+    _belongs_to_module: List[str]
 
     def __init__(self) -> None:
         """Inits an object with default values."""
@@ -2058,6 +2201,7 @@ class RootObjectType(ModelElement):
     _identifier: URI
     _dct_identifier: str
     _g: Graph
+    _belongs_to_module: List[str]
 
     def __init__(self) -> None:
         """Inits an object with default values."""
@@ -2104,12 +2248,18 @@ class RootObjectType(ModelElement):
 class CodeList(ModelElement):
     """A class representing a modelldcatno:CodeList."""
 
-    __slots__ = ("_identifier", "_dct_identifier", "g", "_code_list_reference")
+    __slots__ = (
+        "_identifier",
+        "_dct_identifier",
+        "g",
+        "_code_list_reference",
+    )
 
     _identifier: URI
     _dct_identifier: str
     _g: Graph
     _code_list_reference: CodeList
+    _belongs_to_module: List[str]
 
     def __init__(self) -> None:
         """Inits an object with default values."""
